@@ -16,7 +16,11 @@ class setup:
         print()
         if self.raise_error:
             raise Exception('Raiser') from exception
-    def send_message(self, message):
-        self.bot.send_message(self.channel, message)
-        print(message)
+    def send_message(self, *messages):
+        final_message = ''
+        for message in messages:
+            final_message += message
+            final_message += ' '
+        self.bot.send_message(self.channel, final_message)
+        print(final_message)
         print()
\ No newline at end of file
